==> owncloud-8.1.0p2.tgz: owncloud/apps/files_external/l10n/it.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Il recupero dei token di richiesta non è riuscito. Verifica che la chiave e il segreto dell'applicazione Dropbox siano corretti.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Il recupero dei token di accesso non è riuscito. Verifica che la chiave e il segreto dell'applicazione Dropbox siano corretti.",
    "Please provide a valid Dropbox app key and secret." : "Fornisci chiave di applicazione e segreto di Dropbox validi.",
    "Step 1 failed. Exception: %s" : "Fase 1 non riuscita. Eccezione: %s",
    "Step 2 failed. Exception: %s" : "Fase 2 non riuscita. Eccezione: %s",
    "External storage" : "Archiviazione esterna",
    "Local" : "Locale",
    "Location" : "Posizione",
    "Amazon S3" : "Amazon S3",
    "Key" : "Chiave",
    "Secret" : "Segreto",
    "Bucket" : "Bucket",
    "Amazon S3 and compliant" : "Amazon S3 e conformi",
    "Access Key" : "Chiave di accesso",
    "Secret Key" : "Chiave segreta",
    "Hostname" : "Nome host",
    "Port" : "Porta",
    "Region" : "Regione",
    "Enable SSL" : "Abilita SSL",
    "Enable Path Style" : "Abilita stile percorsi",
    "App key" : "Chiave applicazione",
    "App secret" : "Segreto applicazione",
    "Host" : "Host",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Remote subfolder" : "Sottocartella remota",
    "Secure ftps://" : "Sicuro ftps://",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Region (optional for OpenStack Object Storage)" : "Regione (facoltativa per OpenStack Object Storage)",
    "API Key (required for Rackspace Cloud Files)" : "Chiave API (richiesta per Rackspace Cloud Files)",
    "Tenantname (required for OpenStack Object Storage)" : "Nome tenant (richiesto per OpenStack Object Storage)",
    "Password (required for OpenStack Object Storage)" : "Password (richiesta per OpenStack Object Storage)",
    "Service Name (required for OpenStack Object Storage)" : "Nome servizio (richiesta per OpenStack Object Storage)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "URL del servizio di identità (richiesto per OpenStack Object Storage)",
    "Timeout of HTTP requests in seconds" : "Tempo massimo in secondi delle richieste HTTP",
    "Share" : "Condividi",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizzando le credenziali di OC",
    "Username as share" : "Nome utente come condivisione",
    "URL" : "URL",
    "Secure https://" : "Sicuro https://",
    "SFTP with secret key login" : "SFTP con accesso a chiave segreta",
    "Public key" : "Chiave pubblica",
    "Storage with id \"%i\" not found" : "Archiviazione con ID \"%i\" non trovata",
    "Invalid mount point" : "Punto di mount non valido",
    "Invalid storage backend \"%s\"" : "Motore di archiviazione \"%s\" non valido",
    "Access granted" : "Accesso consentito",
    "Error configuring Dropbox storage" : "Errore durante la configurazione dell'archivio Dropbox",
    "Grant access" : "Concedi l'accesso",
    "Error configuring Google Drive storage" : "Errore durante la configurazione dell'archivio Google Drive",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Enable encryption" : "Abilita cifratura",
    "Enable previews" : "Abilita le anteprime",
    "Check for changes" : "Controlla le modifiche",
    "Never" : "Mai",
    "Once every direct access" : "Una volta per ogni accesso diretto",
    "Every time the filesystem is used" : "Ogni volta che il filesystem viene utilizzato",
    "All users. Type to select user or group." : "Tutti gli utenti. Digita per selezionare utente o gruppo.",
    "(group)" : "(gruppo)",
    "Saved" : "Salvato",
    "Generate keys" : "Genera la chiavi",
    "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
    "<b>Note:</b> " : "<b>Nota:</b>",
    "and" : "e",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a FTP in PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" non è installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "No external storage configured" : "Nessuna archiviazione esterna configurata",
    "You can add external storages in the personal settings" : "Puoi aggiungere archiviazioni esterne nelle impostazioni personali",
    "Name" : "Nome",
    "Storage type" : "Tipo di archiviazione",
    "Scope" : "Ambito",
    "External Storage" : "Archiviazione esterna",
    "Folder name" : "Nome della cartella",
    "Configuration" : "Configurazione",
    "Available for" : "Disponibile per",
    "Add storage" : "Aggiungi archiviazione",
    "Advanced settings" : "Impostazioni avanzate",
    "Delete" : "Elimina",
    "Enable User External Storage" : "Abilita la memoria esterna dell'utente",
    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente memoria esterna"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files_external/l10n/it.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di richiesta non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di accesso non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Please provide a valid app key and secret." : "Fornisci chiave e segreto dell'applicazione validi.",
    "Step 1 failed. Exception: %s" : "Fase 1 non riuscita. Eccezione: %s",
    "Step 2 failed. Exception: %s" : "Fase 2 non riuscita. Eccezione: %s",
    "External storage" : "Archiviazione esterna",
    "Storage with id \"%i\" not found" : "Archiviazione con ID \"%i\" non trovata",
    "Invalid backend or authentication mechanism class" : "Motore o classe del meccanismo di autenticazione non valido",
    "Invalid mount point" : "Punto di mount non valido",
    "Objectstore forbidden" : "Objectstore vietato",
    "Invalid storage backend \"%s\"" : "Motore di archiviazione \"%s\" non valido",
    "Not permitted to use backend \"%s\"" : "Utilizzo del motore \"%s\" non permesso",
    "Not permitted to use authentication mechanism \"%s\"" : "Utilizzo del meccanismo di autenticazione \"%s\" non permesso",
    "Unsatisfied backend parameters" : "Parametri del motore non soddisfatti",
    "Unsatisfied authentication mechanism parameters" : "Parametri del meccanismo di autenticazione non soddisfatti",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Grant access" : "Concedi l'accesso",
    "Access granted" : "Accesso consentito",
    "Error configuring OAuth1" : "Errore di configurazione OAuth1",
    "Error configuring OAuth2" : "Errore di configurazione OAuth2",
    "Generate keys" : "Genera la chiavi",
    "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
    "Enable encryption" : "Abilita cifratura",
    "Enable previews" : "Abilita le anteprime",
    "Check for changes" : "Controlla le modifiche",
    "Never" : "Mai",
    "Once every direct access" : "Una volta per ogni accesso diretto",
    "Every time the filesystem is used" : "Ogni volta che il filesystem viene utilizzato",
    "All users. Type to select user or group." : "Tutti gli utenti. Digita per selezionare utente o gruppo.",
    "(group)" : "(gruppo)",
    "Saved" : "Salvato",
    "Access key" : "Chiave di accesso",
    "Secret key" : "Chiave segreta",
    "Builtin" : "Integrata",
    "None" : "Nessuno",
    "OAuth1" : "OAuth1",
    "App key" : "Chiave applicazione",
    "App secret" : "Segreto applicazione",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "OpenStack" : "OpenStack",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Tenant name" : "Nome tenant",
    "Identity endpoint URL" : "URL endpoint delle identità",
    "Rackspace" : "Rackspace",
    "API key" : "Chiave API",
    "Username and password" : "Nome utente e password",
    "Session credentials" : "Credenziali di sessione",
    "RSA public key" : "Chiave pubblica RSA",
    "Public key" : "Chiave pubblica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome host",
    "Port" : "Porta",
    "Region" : "Regione",
    "Enable SSL" : "Abilita SSL",
    "Enable Path Style" : "Abilita stile percorsi",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sottocartella remota",
    "Secure https://" : "Sicuro https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicuro ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Locale",
    "Location" : "Posizione",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Radice",
    "SFTP with secret key login" : "SFTP con accesso a chiave segreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Condividi",
    "Domain" : "Dominio",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizzando le credenziali di OC",
    "Username as share" : "Nome utente come condivisione",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome servizio",
    "Request timeout (seconds)" : "Tempo massimo della richiesta (secondi)",
    "<b>Note:</b> " : "<b>Nota:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a FTP in PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" non è installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "No external storage configured" : "Nessuna archiviazione esterna configurata",
    "You can add external storages in the personal settings" : "Puoi aggiungere archiviazioni esterne nelle impostazioni personali",
    "Name" : "Nome",
    "Storage type" : "Tipo di archiviazione",
    "Scope" : "Ambito",
    "External Storage" : "Archiviazione esterna",
    "Folder name" : "Nome della cartella",
    "Authentication" : "Autenticazione",
    "Configuration" : "Configurazione",
    "Available for" : "Disponibile per",
    "Advanced settings" : "Impostazioni avanzate",
    "Delete" : "Elimina",
    "Add storage" : "Aggiungi archiviazione",
    "Enable User External Storage" : "Abilita la memoria esterna dell'utente",
    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente memoria esterna"
},
"nplurals=2; plural=(n != 1);");
